@@ -11,12 +11,9 @@ from pdm.cli.options import skip_option
 from pdm.cli.templates import ProjectTemplate
 from pdm.exceptions import PdmUsageError
 from pdm.models.backends import _BACKENDS, DEFAULT_BACKEND, BuildBackend, get_backend
-from pdm.models.python import PythonInfo
 from pdm.models.specifiers import get_specifier
-from pdm.models.venv import get_venv_python
 from pdm.utils import (
     get_user_email_from_git,
-    is_conda_base_python,
     package_installed,
     sanitize_project_name,
     validate_project_name,
@@ -71,11 +68,9 @@ class Command(BaseCommand):
         if not options.template:
             raise PdmUsageError("template argument is required when --cookiecutter is passed")
         if options.project_path:
-            project.core.ui.echo(
+            project.core.ui.warn(
                 "Cookiecutter generator does not respect --project option. "
                 "It will always create a project dir under the current directory",
-                err=True,
-                style="warning",
             )
         try:
             cookiecutter.main([options.template, *options.generator_args], standalone_mode=False)
@@ -111,17 +106,17 @@ class Command(BaseCommand):
     def get_metadata_from_input(self, project: Project, options: argparse.Namespace) -> dict[str, Any]:
         from pdm.formats.base import array_of_inline_tables, make_array, make_inline_table
 
-        is_library = options.lib
-        if not is_library and self.interactive:
-            is_library = termui.confirm(
-                "Is the project a library that is installable?\n"
-                "If yes, we will need to ask a few more questions to include "
-                "the project name and build backend"
+        name = self.ask_project(project)
+        version = self.ask("Project version", "0.1.0")
+        is_dist = options.dist or bool(options.backend)
+        if not is_dist and self.interactive:
+            is_dist = termui.confirm(
+                "Do you want to build this project for distribution(such as wheel)?\n"
+                "If yes, it will be installed by default when running `pdm install`."
             )
         build_backend: type[BuildBackend] | None = None
-        if is_library:
-            name = self.ask_project(project)
-            version = self.ask("Project version", "0.1.0")
+        python = project.python
+        if is_dist:
             description = self.ask("Project description", "")
             if options.backend:
                 build_backend = get_backend(options.backend)
@@ -140,31 +135,33 @@ class Command(BaseCommand):
                 build_backend = get_backend(all_backends[int(selected_backend)])
             else:
                 build_backend = DEFAULT_BACKEND
+            default_python_requires = f">={python.major}.{python.minor}"
         else:
-            name, version, description = "", "", ""
+            description = ""
+            default_python_requires = f"=={python.major}.{python.minor}.*"
         license = self.ask("License(SPDX name)", "MIT")
 
         git_user, git_email = get_user_email_from_git()
         author = self.ask("Author name", git_user)
         email = self.ask("Author email", git_email)
-        python = project.python
-        python_version = f"{python.major}.{python.minor}"
-        python_requires = self.ask("Python requires('*' to allow any)", f">={python_version}")
+        python_requires = self.ask("Python requires('*' to allow any)", default_python_requires)
 
         data = {
             "project": {
                 "name": name,
                 "version": version,
-                "description": description,
                 "authors": array_of_inline_tables([{"name": author, "email": email}]),
                 "license": make_inline_table({"text": license}),
                 "dependencies": make_array([], True),
             },
+            "tool": {"pdm": {"distribution": is_dist}},
         }
 
         if python_requires and python_requires != "*":
             get_specifier(python_requires)
-            data["project"]["requires-python"] = python_requires
+            data["project"]["requires-python"] = python_requires  # type: ignore[index]
+        if description:
+            data["project"]["description"] = description  # type: ignore[index]
         if build_backend is not None:
             data["build-system"] = cast(dict, build_backend.build_system())
 
@@ -200,8 +197,10 @@ class Command(BaseCommand):
             help="Don't ask questions but use default values",
         )
         group.add_argument("--python", help="Specify the Python version/path to use")
-        group.add_argument("--backend", choices=list(_BACKENDS), help="Specify the build backend")
-        group.add_argument("--lib", action="store_true", help="Create a library project")
+        group.add_argument(
+            "--dist", "--lib", dest="dist", action="store_true", help="Create a package for distribution"
+        )
+        group.add_argument("--backend", choices=list(_BACKENDS), help="Specify the build backend, which implies --dist")
         parser.add_argument(
             "template", nargs="?", help="Specify the project template, which can be a local path or a Git URL"
         )
@@ -212,50 +211,20 @@ class Command(BaseCommand):
     def set_python(self, project: Project, python: str | None, hooks: HookManager) -> None:
         from pdm.cli.commands.use import Command as UseCommand
 
-        do_use = UseCommand().do_use
-        if self.interactive:
-            python_info = do_use(
-                project,
-                python or "",
-                first=bool(python),
-                ignore_remembered=True,
-                ignore_requires_python=True,
-                save=False,
-                hooks=hooks,
-            )
-        else:
-            python_info = do_use(
-                project,
-                python or "3",
-                first=True,
-                ignore_remembered=True,
-                ignore_requires_python=True,
-                save=False,
-                hooks=hooks,
-            )
+        python_info = UseCommand().do_use(
+            project,
+            python or "",
+            first=bool(python) or not self.interactive,
+            ignore_remembered=True,
+            ignore_requires_python=True,
+            save=False,
+            hooks=hooks,
+        )
 
-        if project.config["python.use_venv"] and (
-            python_info.get_venv() is None or is_conda_base_python(python_info.path)
-        ):
-            if not self.interactive or termui.confirm(
-                f"Would you like to create a virtualenv with [success]{python_info.executable}[/]?",
-                default=True,
-            ):
-                project._python = python_info
-                try:
-                    path = project._create_virtualenv()
-                    python_info = PythonInfo.from_path(get_venv_python(path))
-                except Exception as e:  # pragma: no cover
-                    project.core.ui.echo(
-                        f"Error occurred when creating virtualenv: {e}\nPlease fix it and create later.",
-                        style="error",
-                        err=True,
-                    )
         if python_info.get_venv() is None:
-            project.core.ui.echo(
+            project.core.ui.info(
                 "You are using the PEP 582 mode, no virtualenv is created.\n"
-                "For more info, please visit https://peps.python.org/pep-0582/",
-                style="success",
+                "For more info, please visit https://peps.python.org/pep-0582/"
             )
         project.python = python_info
 
