@@ -9,7 +9,7 @@ from typing import TYPE_CHECKING
 from pdm.cli.commands.base import BaseCommand
 from pdm.cli.options import verbose_option
 from pdm.environments import BareEnvironment
-from pdm.exceptions import InstallationError
+from pdm.exceptions import InstallationError, PdmArgumentError
 from pdm.models.python import PythonInfo
 
 if TYPE_CHECKING:
@@ -87,17 +87,39 @@ class InstallCommand(BaseCommand):
     arguments = (verbose_option,)
 
     def add_arguments(self, parser: ArgumentParser) -> None:
-        parser.add_argument("version", help="The Python version to install. E.g. cpython@3.10.3", nargs="?")
+        parser.add_argument(
+            "version",
+            help="The Python version to install (e.g. cpython@3.10.3). If left empty, "
+            "highest cPython version that matches this platform/arch is installed. "
+            "If pyproject.toml with requires-python is available, this is considered as well.",
+            nargs="?",
+        )
         parser.add_argument("--list", "-l", action="store_true", help="List all available Python versions")
+        parser.add_argument(
+            "--min",
+            action="store_true",
+            help="Use minimum instead of highest version " "for installation if `version` is left empty",
+        )
 
     def handle(self, project: Project, options: Namespace) -> None:
+        from pbs_installer._install import THIS_ARCH, THIS_PLATFORM
         from pbs_installer._versions import PYTHON_VERSIONS
 
         if options.list:
-            for version in PYTHON_VERSIONS:
-                project.core.ui.echo(str(version))
+            for version, candidates in PYTHON_VERSIONS.items():
+                if (THIS_PLATFORM, THIS_ARCH, True) in candidates:
+                    project.core.ui.echo(str(version))
             return
-        self.install_python(project, options.version)
+        version = options.version
+        if version is None:
+            match = project.get_best_matching_cpython_version(options.min)
+            if match is not None:
+                version = str(match)
+
+        if version is None:
+            raise PdmArgumentError("Please specify a Python version to be installed. E.g. cpython@3.10.3")
+
+        self.install_python(project, version)
 
     @staticmethod
     def install_python(project: Project, request: str) -> PythonInfo:
