@@ -6,7 +6,14 @@ from typing import TYPE_CHECKING, cast
 from pdm.cli.commands.base import BaseCommand
 from pdm.cli.filters import GroupSelection
 from pdm.cli.hooks import HookManager
-from pdm.cli.options import dry_run_option, install_group, lockfile_option, no_lock_option, skip_option, venv_option
+from pdm.cli.options import (
+    dry_run_option,
+    frozen_lockfile_option,
+    install_group,
+    lockfile_option,
+    skip_option,
+    venv_option,
+)
 from pdm.exceptions import PdmUsageError, ProjectError
 
 if TYPE_CHECKING:
@@ -23,7 +30,7 @@ class Command(BaseCommand):
         install_group,
         dry_run_option,
         lockfile_option,
-        no_lock_option,
+        frozen_lockfile_option,
         skip_option,
         venv_option,
     )
@@ -88,7 +95,7 @@ class Command(BaseCommand):
 
         deps, setter = project.use_pyproject_dependencies(group, selection.dev or False)
         project.core.ui.echo(
-            f"Removing packages from [primary]{group}[/] "
+            f"Removing {'[bold]global[/] ' if project.is_global else ''}packages from [primary]{group}[/] "
             f"{'dev-' if selection.dev else ''}dependencies: " + ", ".join(f"[req]{name}[/]" for name in packages)
         )
         with cd(project.root):
@@ -104,9 +111,7 @@ class Command(BaseCommand):
         if not dry_run:
             project.pyproject.write()
         if lock_groups and group not in lock_groups:
-            project.core.ui.echo(
-                f"Group [success]{group}[/] isn't in lockfile, skipping lock.", style="warning", err=True
-            )
+            project.core.ui.warn(f"Group [success]{group}[/] isn't in lockfile, skipping lock.")
             return
         do_lock(project, "reuse", dry_run=dry_run, hooks=hooks, groups=lock_groups)
         if sync:
