@@ -26,7 +26,7 @@ def list_distributions(plugin_only: bool = False) -> list[Distribution]:
     for dist in working_set.values():
         if not plugin_only or any(ep.group in ("pdm", "pdm.plugin") for ep in dist.entry_points):
             result.append(dist)
-    return sorted(result, key=lambda d: d.metadata["Name"] or "UNKNOWN")
+    return sorted(result, key=lambda d: d.metadata.get("Name", "UNKNOWN"))
 
 
 def run_pip(project: Project, args: list[str]) -> subprocess.CompletedProcess[str]:
@@ -96,12 +96,11 @@ class ListCommand(BaseCommand):
         echo("Installed packages:", err=True)
         rows = []
         for dist in distributions:
-            metadata = dist.metadata
             rows.append(
                 (
-                    f"[success]{metadata['Name']}[/]",
-                    f"[warning]{metadata['Version']}[/]",
-                    metadata["Summary"] or "",
+                    f"[success]{dist.metadata.get('Name')}[/]",
+                    f"[warning]{dist.metadata.get('Version')}[/]",
+                    dist.metadata.get("Summary", ""),
                 ),
             )
         project.core.ui.display_columns(rows)
