@@ -201,8 +201,8 @@ class BaseSynchronizer:
             if not isinstance(dreq, FileRequirement):
                 return True
             url = dreq.get_full_url()
-            if url.startswith("file:"):
-                # We don't know whether local files are changed, always update
+            if dreq.is_local_dir:
+                # We don't know whether a local dir has been changed, always update
                 return True
             assert can.link is not None
             return url != backend.expand_line(can.link.url_without_fragment)
