@@ -12,6 +12,7 @@ from pathlib import Path
 from typing import TYPE_CHECKING, Any, Callable, Iterable, Mapping, cast
 
 import tomlkit
+from pbs_installer import PythonVersion
 from tomlkit.items import Array
 
 from pdm import termui
@@ -645,8 +646,6 @@ class Project:
         """Iterate over all interpreters that matches the given specifier.
         And optionally install the interpreter if not found.
         """
-        from pbs_installer._versions import PYTHON_VERSIONS, PythonVersion
-
         from pdm.cli.commands.python import InstallCommand
 
         found = False
@@ -657,12 +656,9 @@ class Project:
         if found or self.is_global:
             return
 
-        def get_version(version: PythonVersion) -> str:
-            return f"{version.major}.{version.minor}.{version.micro}"
-
         if not python_spec:  # handle both empty string and None
             # Get the best match meeting the requires-python
-            best_match = next((v for v in PYTHON_VERSIONS if get_version(v) in self.python_requires), None)
+            best_match = self.get_best_matching_cpython_version()
             if best_match is None:
                 return
             python_spec = str(best_match)
@@ -782,3 +778,36 @@ class Project:
         Returns `None` if both the environment variable and the key does not exists.
         """
         return os.getenv(var.upper()) or self.get_setting(key)
+
+    def _get_matching_python_versions(self) -> list[PythonVersion]:
+        """Get matches meeting the requires-python and current platform/arch combination for cPython"""
+        from pbs_installer._install import THIS_ARCH, THIS_PLATFORM
+        from pbs_installer._versions import PYTHON_VERSIONS
+
+        def get_version(version: PythonVersion) -> str:
+            return f"{version.major}.{version.minor}.{version.micro}"
+
+        arch = "x86" if THIS_ARCH == "32" else THIS_ARCH
+        matches = [
+            v
+            for v, u in PYTHON_VERSIONS.items()
+            if get_version(v) in self.python_requires
+            and v.implementation.lower() == "cpython"
+            and u.get((THIS_PLATFORM, arch, True))
+        ]
+        return matches
+
+    def get_best_matching_cpython_version(self, use_minimum: bool | None = False) -> PythonVersion | None:
+        """
+        Returns the best matching cPython version that fits requires-python, this platform and arch.
+        If no best match could be found, return None.
+
+        Default for best match is "highest" possible interpreter version. If "minimum" shall be used,
+        set `use_minimum` to True.
+        """
+        matches = self._get_matching_python_versions()
+        if matches:
+            if use_minimum is None or not use_minimum:
+                return max(matches, key=lambda v: (v.major, v.minor, v.micro))
+            return min(matches, key=lambda v: (v.major, v.minor, v.micro))
+        return None
